@@ -1,7 +1,7 @@
 package Log::Any::DBI::Query;
 
-our $DATE = '2016-01-23'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-02-11'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ sub _precall_logger {
 sub _postcall_logger {
     my $args = shift;
 
-    $log->tracef("D1: %s", $args->{name});
+    #$log->tracef("D1: %s", $args->{name});
 
     my ($meth) = $args->{name} =~ /.+::(.+)/;
     return if $meth =~ /\Aprepare\z/;
@@ -82,7 +82,7 @@ Log::Any::DBI::Query - Log DBI queries (and results)
 
 =head1 VERSION
 
-This document describes version 0.04 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-01-23.
+This document describes version 0.05 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-02-11.
 
 =head1 SYNOPSIS
 
